==> webkit2gtk_2.50.1.orig.tar.xz: webkitgtk-2.50.1/Source/WebCore/page/scrolling/coordinated/ScrollingTreeCoordinated.h <==
/*
 * Copyright (C) 2018, 2024 Igalia S.L.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials provided
 *    with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(ASYNC_SCROLLING) && USE(COORDINATED_GRAPHICS)

#include "ThreadedScrollingTree.h"

namespace WebCore {

class ScrollingTreeCoordinated final : public ThreadedScrollingTree {
public:
    static Ref<ScrollingTreeCoordinated> create(AsyncScrollingCoordinator&);

    void didCompletePlatformRenderingUpdate();

private:
    explicit ScrollingTreeCoordinated(AsyncScrollingCoordinator&);

    bool isScrollingTreeCoordinated() const final { return true; }

    Ref<ScrollingTreeNode> createScrollingTreeNode(ScrollingNodeType, ScrollingNodeID) override;

    void applyLayerPositionsInternal() final;
    void didCompleteRenderingUpdate() final;

    RefPtr<ScrollingTreeNode> scrollingNodeForPoint(FloatPoint) final;
};

} // namespace WebCore

SPECIALIZE_TYPE_TRAITS_SCROLLING_TREE(WebCore::ScrollingTreeCoordinated, isScrollingTreeCoordinated())

#endif // ENABLE(ASYNC_SCROLLING) && USE(COORDINATED_GRAPHICS)

==> webkit2gtk_2.51.91.orig.tar.xz: webkitgtk-2.51.91/Source/WebCore/page/scrolling/coordinated/ScrollingTreeCoordinated.h <==
/*
 * Copyright (C) 2018, 2024 Igalia S.L.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials provided
 *    with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(ASYNC_SCROLLING) && USE(COORDINATED_GRAPHICS)

#include "ThreadedScrollingTree.h"

namespace WebCore {

class ScrollingTreeCoordinated final : public ThreadedScrollingTree {
public:
    static Ref<ScrollingTreeCoordinated> create(AsyncScrollingCoordinator&);

    void didCompletePlatformRenderingUpdate();

private:
    explicit ScrollingTreeCoordinated(AsyncScrollingCoordinator&);

    bool isScrollingTreeCoordinated() const final { return true; }

    Ref<ScrollingTreeNode> createScrollingTreeNode(ScrollingNodeType, ScrollingNodeID) override;

    void applyLayerPositionsInternal() final;
    void didCompleteRenderingUpdate() final;

#if HAVE(DISPLAY_LINK)
    // ScrollingTree
    void hasNodeWithAnimatedScrollChanged(bool /* hasNodeWithAnimatedScroll */) final;
#endif

    RefPtr<ScrollingTreeNode> scrollingNodeForPoint(FloatPoint) final;
};

} // namespace WebCore

SPECIALIZE_TYPE_TRAITS_SCROLLING_TREE(WebCore::ScrollingTreeCoordinated, isScrollingTreeCoordinated())

#endif // ENABLE(ASYNC_SCROLLING) && USE(COORDINATED_GRAPHICS)
